/* EmblImpl.java
 *
 * created: Tue May 11 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/flatimpl/EmblImpl.java,v 1.2 1999/06/01 18:48:22 kmr Exp $
 */

import uk.ac.sanger.pathogens.*;
import uk.ac.sanger.pathogens.embl.*;

import nsdb.*;
import type.*;
import seqdb.*;

import java.io.*;

/**
 *  EmblImpl class
 *
 *  @author Kim Rutherford
 *  @version $Id: EmblImpl.java,v 1.2 1999/06/01 18:48:22 kmr Exp $
 **/

public class EmblImpl extends _EmblImplBase {
  //
  // IDL:nsdb/Embl/getEmblSeq:1.0
  //
  /**
   * retrieve Nucleotide sequence, given it's accession number. If a client
   * only supports NucSeq, and not EmblSeq, than it can widen the EmblSeq to a
   * NucSeq (implicit).
   * @raises type::NoResult if the accession number does not exist.
   * @raises Superceded if the sequence referenced by the accession
   *   number does not exist any more, because it was merged, or split.
   **/
  public EmblSeq getEmblSeq (final String bio_seq_id)
      throws NoResult, nsdb.EmblPackage.Superceded {
    System.err.println ("getting: " + bio_seq_id);

    final String program_file_name = "/usr/local/pubseq/bin/efetch";

    final String [] arguments = {
      "/bin/sh",
      "-c",
      program_file_name + " " + bio_seq_id + " >" + bio_seq_id
    };

    try {
      final Process process =
        Runtime.getRuntime ().exec (arguments, null);
      
      final InputStream in_stream = process.getInputStream ();

      final FileOutputStream out_file = new FileOutputStream (bio_seq_id);

      final byte [] buffer = new byte [100000];

      while (true) {
        final int read_length = in_stream.read (buffer);

        if (read_length == -1) {
          break;
        }
        
        out_file.write (buffer, 0, read_length);

        if (read_length < 100000) {
          break;
        }
      }

      return new EmblSeqWriterImpl (new File (bio_seq_id));
    } catch (IOException e) {
      e.printStackTrace ();
      throw new NoResult ();
    } catch (InvalidRelationException e) {
      e.printStackTrace ();
      throw new NoResult ();
    }
  }
}
