/* EmblWriterImpl.java
 *
 * created: Fri May 21 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/flatimpl/EmblWriterImpl.java,v 1.3.2.2 2000/09/20 14:27:46 kmr Exp $
 */

import uk.ac.sanger.pathogens.*;
import uk.ac.sanger.pathogens.embl.*;

import nsdb.*;
import type.*;
import seqdb.*;

import java.io.*;

/**
 *  An implementation of the EmblWriter class.
 *
 *  @author Kim Rutherford
 *  @version $Id: EmblWriterImpl.java,v 1.3.2.2 2000/09/20 14:27:46 kmr Exp $
 **/

public class EmblWriterImpl extends _EmblWriterImplBase {
  //
  // IDL:nsdb/Embl/getEmblSeq:1.0
  //
  /**
   * retrieve Nucleotide sequence, given it's accession number. If a client
   * only supports NucSeq, and not EmblSeq, than it can widen the EmblSeq to a
   * NucSeq (implicit).
   * @raises type::NoResult if the accession number does not exist.
   * @raises Superceded if the sequence referenced by the accession
   *   number does not exist any more, because it was merged, or split.
   **/
  public EmblSeq getEmblSeq (final String bio_seq_id)
      throws NoResult, nsdb.EmblPackage.Superceded {
    System.err.println ("getting: " + bio_seq_id);

    return null;
  }

  //
  // IDL:nsdb/Embl/getEmblSeq:1.0
  //
  /**
   * Retrieve a writable Nucleotide sequence object, given it's
   * id number.
   * @raises type.NoResult if the accession number does not exist.
   * @raises Superceded if the sequence referenced by the accession
   *   number does not exist any more, because it was merged, or split.
   */
  public EmblSeqWriter getEmblSeqWriter (final String bio_seq_id)
      throws NoResult {
    
    try {
      // check to see if we have an implementation already
      final EmblSeqWriter current_embl_seq_writer =
        (EmblSeqWriter) hash.get (bio_seq_id);

      if (current_embl_seq_writer == null) {
        // make an implementation
        final EmblSeqWriter new_impl =
          new EmblSeqWriterImpl (new File (bio_seq_id));

        hash.put (bio_seq_id, new_impl);

        return new_impl;
      } else {
        return current_embl_seq_writer;
      }
    } catch (IOException e) {
      e.printStackTrace ();
      throw new NoResult ();
    } catch (InvalidRelationException e) {
      e.printStackTrace ();
      throw new NoResult ();
    }
  };

  /**
   *  Return a ServerInfo structure for the server.
   **/
  public ServerInfo getServerInfo () {
    final java.util.Enumeration bio_seq_ids = hash.keys ();

    final int id_count = hash.size ();

    final EntryStats [] entry_info = new EntryStats [id_count];

    int i = 0;
    while (bio_seq_ids.hasMoreElements ()) {
      final String name = (String) bio_seq_ids.nextElement ();

      entry_info [i] = new EntryStats ();

      entry_info [i].name = name;
      entry_info [i].last_change_time =
        (int)(new File (name).lastModified () / 1000);
      i++;
    }

    final String [] unsorted_file_list =
       new File (".").list (new FilenameFilter () {
         public boolean accept(File dir,
                               String name) {
           if (name.startsWith (".")) {
             return false;
           } else {
             return true;
           }
         }
       });

    final StringVector tmp_vector = new StringVector (unsorted_file_list);

    tmp_vector.sort ();

    final String [] file_list = tmp_vector.getArray ();

    final int file_count;

    if (file_list != null) {
      file_count = file_list.length;
    } else {
      file_count = 0;
    }

    final EntryStats [] file_info = new EntryStats [file_count];

    for (int j = 0; j < file_count; ++j) {
      file_info [j] = new EntryStats ();
      file_info [j].name = file_list [j];
      file_info [j].last_change_time = 0;
    }

    return new ServerInfo (entry_info, file_info);
  }

  /**
   *  A dictionary used to find existing EmblSeqWriterImpl objects given a
   *  bio_seq_id.
   **/
  private java.util.Hashtable hash = new java.util.Hashtable ();
}
