/* FeatureLocationImpl.java
 *
 * created: Mon May 10 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/flatimpl/FeatureLocationImpl.java,v 1.2 1999/06/01 18:57:28 kmr Exp $
 */

import uk.ac.sanger.pathogens.*;
import uk.ac.sanger.pathogens.embl.*;

import nsdb.*;
import type.*;

/**
 *  FeatureLocationImpl class
 *
 *  @author Kim Rutherford
 *  @version $Id: FeatureLocationImpl.java,v 1.2 1999/06/01 18:57:28 kmr Exp $
 **/

public class FeatureLocationImpl extends nsdb._FeatureLocationImplBase {
  /**
   *  
   **/
  public FeatureLocationImpl (Feature feature) {
    this.feature = feature;
  }

  //
  // IDL:nsdb/Location/getLocationString:1.0
  //
  /**
   * retrieve 
   * <A href="http://www.ebi.ac.uk/ebi_docs/embl_db/ft/components.html#location">
   * string representation of location</A>
   **/
  public String getLocationString () {
    return feature.getLocation ().toString ();
  }

  //
  // IDL:nsdb/Location/getNodes:1.0
  //
  /**
   * retrieve tree representation of location
   **/
  public nsdb.LocationPackage.LocationNode_u [] getNodes () {
    return null;
  }

  //
  // IDL:nsdb/FeatureLocation/getNucFeature:1.0
  //
  /**
   * nucfeature to which the location is associated
   **/
  public NucFeature getNucFeature() {
    return (NucFeature) feature.getUserData ();
  }

  //
  // IDL:nsdb/Location/getSeq:1.0
  //
  /**
   * Create nucleotide sequence defined by location. This can imply getting
   * fragments from multiple sequences and concatenating.
   * If it is not possible to resolve the location into a single sequence
   * (e.g. when it contains a 'group' operator, or gap nodes)
   * each fragment will be returned as a seperate string. No assumption should be
   * made on the order, if multiple fragments are returned
   * @raises InexactLocation if an exact sequence cannot be
   *   determined due to the location being inexact
   **/
  public String getSeq()
      throws InexactLocation {
    return null;
  }


  final Feature feature;
}

