/* NucFeatureImpl.java
 *
 * created: Mon May 10 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/flatimpl/NucFeatureImpl.java,v 1.2 1999/06/01 18:58:25 kmr Exp $
 */

import uk.ac.sanger.pathogens.*;
import uk.ac.sanger.pathogens.embl.*;

import nsdb.*;
import type.*;
import seqdb.*;
import nsdb.NucFeaturePackage.QualifierValue_u;

/**
 *  NucFeatureImpl class
 *
 *  @author Kim Rutherford
 *  @version $Id: NucFeatureImpl.java,v 1.2 1999/06/01 18:58:25 kmr Exp $
 **/

public class NucFeatureImpl extends nsdb._NucFeatureImplBase {
  /**
   *  Create a 
   **/
  public NucFeatureImpl (final uk.ac.sanger.pathogens.embl.Feature feature) {
    this.feature = feature;
  }

  //
  // IDL:nsdb/NucFeature/getQualifiers:1.0
  //
  /**
   * Retrieve sequence of qualifiers.
   * @raises type::NoResult if no qualifiers are associated with
   *    the feature.
   **/
  public nsdb.NucFeaturePackage.Qualifier [] getQualifiers ()
      throws NoResult {
    final QualifierVector qualifiers = feature.getQualifiers ();

    final nsdb.NucFeaturePackage.Qualifier [] nuc_qualifiers =
      new nsdb.NucFeaturePackage.Qualifier [qualifiers.size ()];

    for (int i = 0 ; i < qualifiers.size () ; ++i) {
      final String name = qualifiers.elementAt (i).getName ();
      final StringVector values = qualifiers.elementAt (i).getValues ();

      final QualifierValue_u [] nuc_qualifier_values =
        new QualifierValue_u [values == null ? 0 : values.size ()];

      for (int value_index = 0 ;
           value_index < nuc_qualifier_values.length ;
           ++value_index) {
        final QualifierValue_u qualifier_value_u = new QualifierValue_u ();

        nuc_qualifier_values [value_index] = qualifier_value_u;
        qualifier_value_u.text (values.elementAt (value_index));
      }

      nuc_qualifiers [i] =
        new nsdb.NucFeaturePackage.Qualifier (name, nuc_qualifier_values);
    }

    return nuc_qualifiers;
  }
  
  //
  // IDL:nsdb/NucFeature/getQualifier:1.0
  //
  /**
   * retrieve qualifier of a certain type.
   * To find out which qualifier/feature combinations are valid, a client should
   * query the NucFeatureMeta server.
   * @raises type::NoResult if no qualifier of this type is associated with
   *   the feature
   * @raises type::InvalidRelation if the requested qualifier cannot be
   *   associated to the current feature type
   * @see metafeature::NucFeatureMeta
   **/
  public nsdb.NucFeaturePackage.Qualifier getQualifier (String qualifier_name)
      throws NoResult, InvalidRelation {
    throw new NoResult ();
  }
  
  //
  // IDL:nsdb/NucFeature/getNucSeqs:1.0
  //
  /**
   * If the location of the feature references multiple sequences, get a 
   * sequence of all sequences referenced
   * This method is equivalent to retrieving the feature location, and looping
   *  through all location nodes to find the referenced sequences, converting 
   * the accession numbers into DbXref's.
   **/
  public DbXref [] getNucSeqs () {
    return null;
  }
  
  //
  // IDL:nsdb/NucFeature/getLocation:1.0
  //
  /**
   * retrieve location of feature.
   * @raises type::NoResult if no location is associated with the feature.
   **/
  public FeatureLocation getLocation ()
      throws type.NoResult {
    return new FeatureLocationImpl (getDbFeature ());
  }

  //
  // IDL:seqdb/Feature/getFeatureId:1.0
  //
  /**
   * feature identifier.
   **/
  public String getFeatureId () {
    return null;
  }
  
  //
  // IDL:seqdb/Feature/getKey:1.0
  //
  /**
   * Feature types are defined by a key.
   **/
  public String getKey () {
    return feature.getKey ().toString ();
  }
  
  //
  // IDL:seqdb/Feature/getFeatureVersion:1.0
  //
  /**
   * return current version of the feature. returns 0 if 
   * no versioning is implemented.
   **/
  public int getFeatureVersion () {
    return 0;
  }

  /**
   *  
   **/
  public uk.ac.sanger.pathogens.embl.Feature getDbFeature () {
    return feature;
  }

  /**
   *  The Feature that was passed to the constructor.
   **/
  private uk.ac.sanger.pathogens.embl.Feature feature;
}
